#include "mainwindow.h"

#include "sellerdialog.h"

#include <regex>

constexpr int STATUSBAR_TIMEOUT = 5000;

MainWindow::MainWindow()
{
    ui_.setupUi(this);

    connect(ui_.actionQuit, &QAction::triggered, qApp, QApplication::quit);
    connect(ui_.actionEditSeller, &QAction::triggered, this,
            &MainWindow::on_actionEditSeller_triggered);
    connect(ui_.sellerNoEdit, &QLineEdit::returnPressed, this,
            &MainWindow::on_sellerNoEdit_checkSellerNo);

    marketplace_ = std::make_unique<Marketplace>();
    marketplace_->loadFromDb();
    statusBar()->showMessage("Gespeicherte Daten wurden geladen.", STATUSBAR_TIMEOUT);
}

void MainWindow::on_actionEditSeller_triggered()
{
    auto dialog = std::make_unique<SellerDialog>(this);
    int retCode = dialog->exec();
    if (retCode == QDialog::Accepted) {
        marketplace_->sortSellers();
        marketplace_->storeToDb();
        statusBar()->showMessage("Änderungen an den Verkäufer-Stammdaten gespeichert.",
                                 STATUSBAR_TIMEOUT);
    } else {
        marketplace_->loadFromDb();
        statusBar()->showMessage("Änderungen an den Verkäufer-Stammdaten verworfen!",
                                 STATUSBAR_TIMEOUT);
    }
}

void MainWindow::on_sellerNoEdit_checkSellerNo()
{
    using std::regex, std::regex_match, std::smatch;

    auto inputText = ui_.sellerNoEdit->text().toStdString();

    if (inputText.empty()) {

        return;
    }

    regex pattern{R"(\d{1,5})"};
    smatch result;
    if (!regex_match(inputText, result, pattern)) {
        return;
    }
    int sellerNo = std::stoi(result[0]);

    auto seller = marketplace_->findSellerWithSellerNo(sellerNo);
    if (seller) {
        std::cout << "!!! Seller gefunden: " << seller->getFirstName() << "\n";
        // TODO: Warenkorb füllen
    }
    
    ui_.sellerNoEdit->clear();
}